# Generated by Django 3.2.9 on 2025-02-08 13:39

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('django_url_group_permissions', '0001_initial'),
    ]

    operations = [
        migrations.RemoveIndex(
            model_name='groupurlpermissions',
            name='django_url__url_7c741b_idx',
        ),
        migrations.RemoveIndex(
            model_name='groupurlpermissions',
            name='django_url__http_me_61e08d_idx',
        ),
        migrations.AddIndex(
            model_name='groupurlpermissions',
            index=models.Index(fields=['url'], name='django_url__url_ba8d57_idx'),
        ),
        migrations.AddIndex(
            model_name='groupurlpermissions',
            index=models.Index(fields=['http_method'], name='django_url__http_me_43a03c_idx'),
        ),
    ]
